@@ -27,6 +27,7 @@ from gajim.common import events
 from gajim.common import app
 from gajim.common import contacts
 from gajim.common import ged
+from gajim.common.helpers import AdditionalDataDict
 from gajim.common.const import KindConstant
 from gajim.gtk.single_message import SingleMessageWindow
 
@@ -78,11 +79,13 @@ class ChatControlSession:
         """
         if obj.session != self:
             return
-        contact = app.contacts.get_contact(self.conn.name, obj.jid,
-            obj.resource)
-        if not contact:
-            contact = app.contacts.get_gc_contact(self.conn.name, obj.jid,
-                obj.resource)
+
+        if obj.muc_pm:
+            contact = app.contacts.get_gc_contact(
+                self.conn.name, obj.jid, obj.resource)
+        else:
+            contact = app.contacts.get_contact(
+                self.conn.name, obj.jid, obj.resource)
         if self.resource != obj.resource:
             self.resource = obj.resource
             if self.control:
@@ -277,7 +280,7 @@ class ChatControlSession:
         fjid = jid
 
         if additional_data is None:
-            additional_data = {}
+            additional_data = AdditionalDataDict()
 
         # Try to catch the contact with correct resource
         if resource:
